from .core.scheduler import LLMScheduler, LLMSchedulerConfig
from .core.tool_registry import ToolRegistry
from .tools.base.tool import BaseTool, ToolMetadata, ToolParameter
from .core.storage import BaseStorage, SQLiteStorage, SupabaseStorage
from .utils import create_scheduler

__version__ = "0.2.0"

__all__ = [
    "LLMScheduler",
    "LLMSchedulerConfig",
    "ToolRegistry",
    "BaseTool",
    "ToolMetadata",
    "ToolParameter",
    "BaseStorage",
    "SQLiteStorage",
    "SupabaseStorage",
    "create_scheduler",
] 


import asyncio
from typing import Optional
from .core.scheduler import LLMScheduler

def create_scheduler(config: dict, registry: Optional['ToolRegistry'] = None) -> LLMScheduler:
    """Create a scheduler synchronously"""
    async def _create():
        return LLMScheduler(config=config, tool_registry=registry)
    
    loop = asyncio.new_event_loop()
    asyncio.set_event_loop(loop)
    try:
        return loop.run_until_complete(_create())
    finally:
        loop.close() 